'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var clientS3 = require('@aws-sdk/client-s3');
var umi = require('@metaplex-foundation/umi');

function createAwsUploader(client, bucketName) {
  const uploadOne = async file => {
    const command = new clientS3.PutObjectCommand({
      Bucket: bucketName,
      Key: file.uniqueName,
      Body: file.buffer,
      ContentType: file.contentType || undefined
    });
    await client.send(command);
    return getUrl(file.uniqueName);
  };
  const upload = async files => Promise.all(files.map(file => uploadOne(file)));
  const uploadJson = async json => {
    const file = umi.createGenericFileFromJson(json);
    const uris = await upload([file]);
    return uris[0];
  };
  const getUploadPrice = async () => umi.lamports(0);
  const getUrl = async key => {
    const region = await client.config.region();
    const encodedKey = encodeURIComponent(key);
    return `https://s3.${region}.amazonaws.com/${bucketName}/${encodedKey}`;
  };
  return {
    upload,
    uploadJson,
    getUploadPrice,
    getUrl
  };
}

exports.createAwsUploader = createAwsUploader;
//# sourceMappingURL=createAwsUploader.cjs.map
