import { PutObjectCommand } from '@aws-sdk/client-s3';
import { createGenericFileFromJson, lamports } from '@metaplex-foundation/umi';

function createAwsUploader(client, bucketName) {
  const uploadOne = async file => {
    const command = new PutObjectCommand({
      Bucket: bucketName,
      Key: file.uniqueName,
      Body: file.buffer,
      ContentType: file.contentType || undefined
    });
    await client.send(command);
    return getUrl(file.uniqueName);
  };
  const upload = async files => Promise.all(files.map(file => uploadOne(file)));
  const uploadJson = async json => {
    const file = createGenericFileFromJson(json);
    const uris = await upload([file]);
    return uris[0];
  };
  const getUploadPrice = async () => lamports(0);
  const getUrl = async key => {
    const region = await client.config.region();
    const encodedKey = encodeURIComponent(key);
    return `https://s3.${region}.amazonaws.com/${bucketName}/${encodedKey}`;
  };
  return {
    upload,
    uploadJson,
    getUploadPrice,
    getUrl
  };
}

export { createAwsUploader };
//# sourceMappingURL=createAwsUploader.mjs.map
